@@ -1475,6 +1475,11 @@ class ParseIni(object):
         if not env_list:
             env_list = all_envs
 
+        provision_tox_env = config.provision_tox_env
+        if config.provision_tox_env in env_list:
+            msg = "provision_tox_env {} cannot be part of envlist".format(provision_tox_env)
+            raise tox.exception.ConfigError(msg)
+
         package_env = config.isolated_build_env
         if config.isolated_build is True and package_env in all_envs:
             all_envs.remove(package_env)
@@ -1482,6 +1487,7 @@ class ParseIni(object):
         if config.isolated_build is True and package_env in env_list:
             msg = "isolated_build_env {} cannot be part of envlist".format(package_env)
             raise tox.exception.ConfigError(msg)
+
         return env_list, all_envs, _split_env(from_config), envlist_explicit
 
     @staticmethod
@@ -1848,10 +1854,23 @@ class Replacer:
             return os.pathsep
 
         default_value = g["default_value"]
+        # special case: opts and packages. Leave {opts} and
+        # {packages} intact, they are replaced manually in
+        # _venv.VirtualEnv.run_install_command.
+        if sub_value in ("opts", "packages"):
+            return "{{{}}}".format(sub_value)
+
         if sub_value == "posargs":
             return self.reader.getposargs(default_value)
 
         sub_type = g["sub_type"]
+        if sub_type == "posargs":
+            if default_value:
+                value = "{}:{}".format(sub_value, default_value)
+            else:
+                value = sub_value
+            return self.reader.getposargs(value)
+
         if not sub_type and not sub_value:
             raise tox.exception.ConfigError(
                 "Malformed substitution; no substitution type provided. "
